package mi.hdm.controllers.components;

import javafx.fxml.FXML;
import javafx.scene.control.Button;
import javafx.scene.control.TextField;
import javafx.scene.image.Image;
import javafx.scene.image.ImageView;
import mi.hdm.GUIDriver;
import mi.hdm.controllers.BaseController;
import mi.hdm.controllers.View;
import mi.hdm.filesystem.FileManager;
import mi.hdm.recipes.IngredientManager;
import mi.hdm.recipes.Recipe;
import mi.hdm.recipes.RecipeManager;
import mi.hdm.recipes.RecipeSearch;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import java.util.List;
import java.util.Objects;

public class HeaderController extends BaseController {
    //TODO: searching needs to update the view! -> just delete the header as separate component and integrate it into MainPageController
    private final static Logger log = LogManager.getLogger(HeaderController.class);

    @FXML
    private TextField searchBox;
    @FXML
    private Button musicButton;
    @FXML
    private ImageView musicButtonImageView;

    private final String PATH_TO_SOUND_ON = "/images/Tasty_Pages_sound_on.png";
    private final String PATH_TO_SOUND_OFF = "/images/Tasty_Pages_sound_off.png";

    private final RecipeManager recipeManager;
    private final IngredientManager ingredientManager;
    private List<Recipe> lastSearchResults;

    public HeaderController(RecipeManager recipeManager, IngredientManager ingredientManager) {
        this.recipeManager = recipeManager;
        this.ingredientManager = ingredientManager;
        lastSearchResults = recipeManager.getRecipes();
    }

    @FXML
    public void searchByQuery() {
        changeScene(View.MAIN);
        String query = searchBox.getText();
        log.debug("User submitted search box");
        RecipeSearch recipeSearch = new RecipeSearch(recipeManager, ingredientManager);
        lastSearchResults = recipeSearch.searchByQuery(recipeManager.getRecipes(), query); //TODO: pass last search results
        System.out.println("Results: ");
        lastSearchResults.forEach(result -> System.out.println("   " + result.getName()));
    }

    @FXML
    public void changeSceneToHome() {
        changeScene(View.MAIN);
    }

    @FXML
    public void changeSceneToShoppingList() {
        changeScene(View.SHOPPINGLIST_VIEW);
    }

    @FXML
    public void changeSceneToMealPlan() {
        changeScene(View.MEALPLAN_VIEW);
    }

    @FXML
    public void changeSceneToIngredientCreator() {
        changeScene(View.INGREDIENT_CREATOR);
    }

    public void changeSceneToCategoryCreator() {
        changeScene(View.CATEGORY_CREATOR);
    }

    public void handleMusicSetting() {

        final String ABSOLUTE_PATH_TO_SOUND_ON = FileManager.getAbsolutePathFromResourceFolder(PATH_TO_SOUND_ON);
        log.info("Found path to image: {}", ABSOLUTE_PATH_TO_SOUND_ON);
        final String ABSOLUTE_PATH_TO_SOUND_OFF = FileManager.getAbsolutePathFromResourceFolder(PATH_TO_SOUND_OFF);
        log.info("Found path to image: {}", ABSOLUTE_PATH_TO_SOUND_OFF);

        if (ABSOLUTE_PATH_TO_SOUND_OFF != null && ABSOLUTE_PATH_TO_SOUND_ON != null) {

            Image image;
            if(GUIDriver.getCurrentMusicState()){
                //image = new Image(ABSOLUTE_PATH_TO_SOUND_OFF);
                log.debug("User wants to stop music");
            } else {
                //image = new Image(ABSOLUTE_PATH_TO_SOUND_ON);
                log.info("User wants to start music");
            }
            //musicButtonImageView.setImage(image);


        } else {
            log.error("Path is null");
        }
        GUIDriver.changeCurrentMusicState();

    }
}
